baseObjects.User

|  | ## Cheshire3 Object Model: Class User

Module baseObjects :: Class User

## Class User
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                           User

Known Subclasses:
  user.SimpleUser

An object representing a user of the system to allow for convenient access to properties such as username, password and rights metadata.
Instance Methods

hasFlag(self, session, flag, object=None) Check whether or not the user has the specified flag.
Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

email |
flags |
password |
realName |
rights |
username |
Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### hasFlag(self, session, flag, object=None) | source code
Check whether or not the user has the specified flag. This flag may be set regarding a particular object, for example write access to a particular store.

Class Variable Details

    ### email Value:
        ''

    ### flags Value:
        []

    ### password Value:
        ''

    ### realName Value:
        ''

    ### rights Value:
        []

    ### username Value:
        ''